/*
*********************************************************************************************************
*                                            EXAMPLE CODE
*
*                          (c) Copyright 2009-2014; Micrium, Inc.; Weston, FL
*
*               All rights reserved.  Protected by international copyright laws.
*
*               Please feel free to use any application code labeled as 'EXAMPLE CODE' in
*               your application products.  Example code may be used as is, in whole or in
*               part, or may be used as a reference only.
*
*               Please help us continue to provide the Embedded community with the finest
*               software available.  Your honesty is greatly appreciated.
*
*               You can contact us at www.micrium.com.
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*
*                                          APPLICATION CODE
*
*                                            Renesas RX63N
*                                               on the
*                                              YRDKRX63N
*                                          Evaluation Board
*
* Filename      : app.c
* Version       : V1.00
* Programmer(s) : JM
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                             INCLUDE FILES
*********************************************************************************************************
*/

#include  "app_cfg.h"
#include  "cpu_cfg.h"
#include  "bsp_cfg.h"

#include  <cpu_core.h>
#include  <os.h>

#include  <bsp.h>
#include  <bsp_int_vect_tbl.h>

#if       BSP_CFG_SER_EN       > 0u
#include  <bsp_ser.h>
#endif

#if       BSP_CFG_LED_EN       > 0u
#include  <bsp_led.h>
#endif

#if       BSP_CFG_GRAPH_LCD_EN > 0u
#include  <bsp_glcd.h>
#endif

#if       SPIN_LEDS_APP_EN     > 0u
#include  "spin_led.h"
#endif


/*
*********************************************************************************************************
*                                            LOCAL DEFINES
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                           LOCAL CONSTANTS
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                          LOCAL DATA TYPES
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                       LOCAL GLOBAL VARIABLES
*********************************************************************************************************
*/

static  CPU_STK  AppStartTaskStk[APP_CFG_TASK_START_STK_SIZE];
static  OS_TCB   AppStartTaskTCB;


/*
*********************************************************************************************************
*                                            LOCAL MACRO'S
*********************************************************************************************************
*/


/*
*********************************************************************************************************
*                                      LOCAL FUNCTION PROTOTYPES
*********************************************************************************************************
*/

static  void  AppTaskStart (void  *p_arg);

static  void  AppTaskCreate(void);
static  void  AppObjCreate (void);


/*
*********************************************************************************************************
*                                               main()
*
* Description : Entry point for C code.
*
* Arguments   : none.
*
* Returns     : none.
*
* Note(s)     : (1) It is assumed that your code will call main() once you have performed all necessary
*                   initialization.
*********************************************************************************************************
*/

void  main (void)
{
    OS_ERR  err;



    CPU_IntDis();                                               /* Disable all interrupts.                              */

    BSP_IntVectSet(27, (CPU_FNCT_VOID)OSCtxSwISR);              /* Setup kernel context switch                          */
#ifdef TRC_USE_TRACEALYZER_RECORDER
#if (TRC_CFG_RECORDER_MODE == TRC_RECORDER_MODE_SNAPSHOT)
    vTraceEnable(TRC_START);
    OSInit(&err);                                               /* Init uC/OS-III.                                      */
#else
    OSInit(&err);                                               /* Init uC/OS-III.                                      */
    vTraceEnable(TRC_INIT);
#endif
#endif




    OSTaskCreate((OS_TCB     *)&AppStartTaskTCB,                /* Create the start task                                */
                 (CPU_CHAR   *)"Startup Task",
                 (OS_TASK_PTR ) AppTaskStart,
                 (void       *) 0,
                 (OS_PRIO     ) APP_CFG_TASK_START_PRIO,
                 (CPU_STK    *)&AppStartTaskStk[0],
                 (CPU_STK_SIZE) APP_CFG_TASK_START_STK_SIZE / 10u,
                 (CPU_STK_SIZE) APP_CFG_TASK_START_STK_SIZE,
                 (OS_MSG_QTY  ) 0u,
                 (OS_TICK     ) 0u,
                 (void       *) 0,
                 (OS_OPT      )(OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
                 (OS_ERR     *)&err);

    OSStart(&err);                                              /* Start multitasking (i.e. give control to uC/OS-III). */

    while (1) {
        ;
    }
}


/*
*********************************************************************************************************
*                                           App_TaskStart()
*
* Description : Startup task example code.
*
* Arguments   : p_arg       Argument passed by 'OSTaskCreate()'.
*
* Returns     : none.
*
* Created by  : main().
*
* Notes       : (1) The ticker MUST be initialized AFTER multitasking has started.
*********************************************************************************************************
*/

static  void  AppTaskStart (void *p_arg)
{
    CPU_INT08U  status_cnt;
    OS_ERR      os_err;


   (void)&p_arg;

    CPU_Init();                                                 /* Initialize the uC/CPU Services                       */
    Mem_Init();                                                 /* Initialize the Memory Management Module.             */
    BSP_Init();                                                 /* Initialize BSP Functions                             */

#if (OS_CFG_STAT_TASK_EN > 0u)
    OSStatTaskCPUUsageInit(&os_err);                            /* Compute CPU capacity with no task running            */
#endif

#ifdef CPU_CFG_INT_DIS_MEAS_EN
    CPU_IntDisMeasMaxCurReset();
#endif

#if BSP_CFG_SER_EN > 0u
    BSP_Ser_Init(115200u);                                      /* Initialize Serial Communications                     */
#endif

#if BSP_CFG_GRAPH_LCD_EN > 0u
    BSP_GraphLCD_Clear();
    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_LARGE);
    BSP_GraphLCD_String(0u, "   MICRIUM   ");

    BSP_GraphLCD_SetFont(BSP_GLCD_FONT_SMALL);
    BSP_GraphLCD_String(1u, "      OS3 DEMO      ");
#endif

    BSP_LED_Off(0u);

    APP_TRACE_INFO(("Creating Application Tasks...\n\r"));
    AppTaskCreate();                                            /* Creates all the necessary application tasks.         */

    APP_TRACE_INFO(("Creating Application Objects...\n\r"));
    AppObjCreate();                                             /* Creates all the necessary application tasks.         */

    status_cnt = 0u;

    while (DEF_ON) {
        if (status_cnt >= 3u) {
            status_cnt = 0u;
        }

        BSP_GraphLCD_ClrLine(5u);

        switch (status_cnt) {
            case 0u:
                 BSP_GraphLCD_String(5u, "Status: Running.    ");
                 break;

            case 1u:
                 BSP_GraphLCD_String(5u, "Status: Running..   ");
                 break;

            case 2u:
            default:
                 BSP_GraphLCD_String(5u, "Status: Running...  ");
                 break;
        }

        status_cnt++;
        OSTimeDlyHMSM(0u, 0u, 1u, 0u,
                      OS_OPT_TIME_HMSM_STRICT, &os_err);
    }
}


/*
*********************************************************************************************************
*                                         AppTaskCreate()
*
* Description :  Create the application tasks.
*
* Argument(s) :  none.
*
* Return(s)   :  none.
*
* Caller(s)   :  AppTaskStart()
*
* Note(s)     :  none.
*********************************************************************************************************
*/

static  void  AppTaskCreate (void)
{
#if SPIN_LEDS_APP_EN > 0u
    SpinLEDsInit();
#endif
}


/*
*********************************************************************************************************
*                                      AppObjCreate()
*
* Description : Create the application Objects
*
* Argument(s) : none.
*
* Return(s)   : none.
*
* Caller(s)   : AppTasStart()
*
* Note(s)     : none.
*********************************************************************************************************
*/

static  void  AppObjCreate (void)
{
}
