/*
*********************************************************************************************************
*                                            EXAMPLE CODE
*
*                           (c) Copyright 2015; Micrium, Inc.; Weston, FL
*
*               All rights reserved.  Protected by international copyright laws.
*
*               Please feel free to use any application code labeled as 'EXAMPLE CODE' in
*               your application products.  Example code may be used as is, in whole or in
*               part, or may be used as a reference only.
*
*               Please help us continue to provide the Embedded community with the finest
*               software available.  Your honesty is greatly appreciated.
*
*               You can contact us at www.micrium.com.
*********************************************************************************************************
*/

/*
*********************************************************************************************************
*
*                                          APPLICATION CODE
*
*                                            Renesas RX62N
*                                               on the
*                                             YRDKRX62N
*                                          Evaluation Board
*
* Filename      : spin_led.c
* Version       : V1.00
* Programmer(s) : AA
*                 JM
*********************************************************************************************************
*/
/*
*********************************************************************************************************
*                                             INCLUDE FILES
*********************************************************************************************************
*/

#include  <app_cfg.h>
#include  <bsp_cfg.h>

#if SPIN_LEDS_APP_EN > 0u
#if BSP_CFG_LED_EN   > 0u

#include  <cpu.h>
#include  <lib_def.h>
#include  <os.h>

#include  <bsp_led.h>


/*
*********************************************************************************************************
*                                       LOCAL GLOBAL VARIABLES
*********************************************************************************************************
*/

#if       BSP_CFG_OS2_EN   > 0u
static  OS_STK   SpinLEDsTaskStk[SPIN_LEDS_APP_TASK_STK_SIZE];
#endif


#if       BSP_CFG_OS3_EN   > 0u
static  CPU_STK  SpinLEDsTaskStk[SPIN_LEDS_APP_TASK_STK_SIZE];
static  OS_TCB   SpinLEDsTCB;
#endif

/*
*********************************************************************************************************
*                                      LOCAL FUNCTION PROTOTYPES
*********************************************************************************************************
*/

static  void  SpinLEDsSeq0 (void);
static  void  SpinLEDsSeq1 (void);
static  void  SpinLEDsSeq2 (void);
static  void  SpinLEDsSeq3 (void);
static  void  SpinLEDsDly  (CPU_INT16U ms);


/*
*********************************************************************************************************
*                                          SPIN LEDs TASK
*
* Description : Toggles the LEDs in four different sequences.
*
* Arguments   : p_arg   is the argument passed to 'Start()' by 'OSTaskCreate()'.
*
* Returns     : none
*
* Notes       : 1) The first line of code is used to prevent a compiler warning because 'p_arg' is not
*                  used.  The compiler should not generate any code for this statement.
*********************************************************************************************************
*/

void  SpinLEDsTask (void *p_arg)
{
    CPU_INT08U  seq;


    (void)&p_arg;

    BSP_LED_Off(0);                                             /* Turn all LEDs off.                                   */

    seq = 0;

    while (DEF_ON) {                                            /* Task body, always written as an infinite loop.       */

        switch (seq){
            case 0:
                 SpinLEDsSeq0();
                 seq++;
                 break;

            case 1:
                 SpinLEDsSeq1();
                 seq++;
                 break;

            case 2:
                 SpinLEDsSeq2();
                 seq++;
                 break;

            case 3:
                 SpinLEDsSeq3();
                 seq = 0;
                 break;

            default:
                 seq = 0;
                 break;
        }
    }
}


/*
*********************************************************************************************************
*                                    Initialize the Spin LED task
*
* Description :  Create the application tasks.
*
* Argument(s) :  none.
*
* Return(s)   :  none.
*
* Note(s)     :  none.
*********************************************************************************************************
*/

void  SpinLEDsInit (void)
{
#if  BSP_CFG_OS2_EN  > 0u
#if (OS_TASK_NAME_EN > 0u)
    CPU_INT08U  err;
#endif


    OSTaskCreateExt((void (*)(void *)) SpinLEDsTask,           /* Create the LEDs task                                 */
                    (void           *) 0,
                    (OS_STK         *)&SpinLEDsTaskStk[SPIN_LEDS_APP_TASK_STK_SIZE - 1],
                    (INT8U           ) SPIN_LEDS_APP_TASK_PRIO,
                    (INT16U          ) SPIN_LEDS_APP_TASK_PRIO,
                    (OS_STK         *)&SpinLEDsTaskStk[0],
                    (INT32U          ) SPIN_LEDS_APP_TASK_STK_SIZE,
                    (void           *) 0,
                    (INT16U          )(OS_TASK_OPT_STK_CHK | OS_TASK_OPT_STK_CLR));

#if (OS_TASK_NAME_EN > 0u)
    OSTaskNameSet(SPIN_LEDS_APP_TASK_PRIO, (INT8U *)"Spin LEDs Task", &err);
#endif
#endif



#if  BSP_CFG_OS3_EN  > 0u
    OS_ERR  err;


    OSTaskCreate((OS_TCB     *)&SpinLEDsTCB,                 /* Create the LEDs task                                 */
                 (CPU_CHAR   *)"Spin LEDs Task",
                 (OS_TASK_PTR ) SpinLEDsTask,
                 (void       *) 0,
                 (OS_PRIO     ) SPIN_LEDS_APP_TASK_PRIO,
                 (CPU_STK    *)&SpinLEDsTaskStk[0],
                 (CPU_STK_SIZE) SPIN_LEDS_APP_TASK_STK_SIZE / 10u,
                 (CPU_STK_SIZE) SPIN_LEDS_APP_TASK_STK_SIZE,
                 (OS_MSG_QTY  ) 0u,
                 (OS_TICK     ) 0u,
                 (void       *) 0,
                 (OS_OPT      )(OS_OPT_TASK_STK_CHK | OS_OPT_TASK_STK_CLR),
                 (OS_ERR     *)&err);
#endif
    (void)&err;
}


/*
*********************************************************************************************************
*                                         LEDs Sequence #0
*
* Description : This function manipulates the YRDKRX63N's LEDs
*
* Arguments   : none
*
* Returns     : none
*********************************************************************************************************
*/

static  void  SpinLEDsSeq0 (void)
{
    CPU_INT08U  i;


    BSP_LED_Off(0);

    for (i = 14; i > 4; i--) {
        BSP_LED_On(i);
        SpinLEDsDly(100u);

        BSP_LED_Off(i);

        SpinLEDsDly(100u);
    }

    for (i = 4; i <= 15; i++) {
        BSP_LED_On(i);
        SpinLEDsDly(100u);

        BSP_LED_Off(i);
        SpinLEDsDly(100u);
    }
}


/*
*********************************************************************************************************
*                                         LEDs Sequence #1
*
* Description : This function manipulates the YRDKRX63N's LEDs
*
* Arguments   : none
*
* Returns     : none
*********************************************************************************************************
*/

static  void  SpinLEDsSeq1 (void)
{
    CPU_INT08U  i;


    BSP_LED_Off(0);
    for (i = 4; i <= 15; i++) {
        BSP_LED_On(i);
        SpinLEDsDly(200u);
    }

    for (i = 15; i > 4; i--) {
        BSP_LED_Off(i);
        SpinLEDsDly(200u);
    }
}


/*
*********************************************************************************************************
*                                         LEDs Sequence #2
*
* Description : This function manipulates the YRDKRX63N's LEDs
*
* Arguments   : none
*
* Returns     : none
*********************************************************************************************************
*/

static  void  SpinLEDsSeq2 (void)
{
    CPU_INT08U  i;
    CPU_INT08U  j;


    BSP_LED_Off(0);
    j = 15;

    for (i = 4; i <= 9; i++) {
        BSP_LED_On(i);
        BSP_LED_On(j);
        j--;

        SpinLEDsDly(200u);
    }

    j = 15;

    for (i = 4; i <= 8; i++) {
        BSP_LED_Off(i);
        BSP_LED_Off(j);
        j--;

        SpinLEDsDly(200u);
    }

    j = 11;

    for (i = 8; i >= 4; i--) {
        BSP_LED_On(i);
        BSP_LED_On(j);
        j++;

        SpinLEDsDly(200u);
    }

    j = 10;

    for (i = 9; i >= 4; i--) {
        BSP_LED_Off(i);
        BSP_LED_Off(j);
        j++;

        SpinLEDsDly(200u);
    }
}


/*
*********************************************************************************************************
*                                         LEDs Sequence #3
*
* Description : This function manipulates the YRDKRX63N's LEDs
*
* Arguments   : none
*
* Returns     : none
*********************************************************************************************************
*/

static  void  SpinLEDsSeq3 (void)
{
    CPU_INT08U  i;
    CPU_INT08U  delay;


    BSP_LED_Off(0);

    for (delay = 100; delay > 20; delay -= 5) {
        for (i = 4; i < 7; i++) {
            BSP_LED_On(i);
            BSP_LED_On(i + 3);
            BSP_LED_On(i + 6);
            BSP_LED_On(i + 9);

            SpinLEDsDly(delay);

            BSP_LED_Off(i);
            BSP_LED_Off(i + 3);
            BSP_LED_Off(i + 6);
            BSP_LED_Off(i + 9);

            SpinLEDsDly(delay);
        }
    }

    for (delay = 25; delay <= 100; delay += 5) {
        for (i = 4; i < 7; i++) {
            BSP_LED_On(i);
            BSP_LED_On(i + 3);
            BSP_LED_On(i + 6);
            BSP_LED_On(i + 9);

            SpinLEDsDly(delay);

            BSP_LED_Off(i);
            BSP_LED_Off(i + 3);
            BSP_LED_Off(i + 6);
            BSP_LED_Off(i + 9);

            SpinLEDsDly(delay);
        }
    }
}


static  void  SpinLEDsDly  (CPU_INT16U ms)
{
#if  BSP_CFG_OS2_EN  > 0u
    OSTimeDlyHMSM(0u, 0u, 0u, ms);
#endif


#if  BSP_CFG_OS3_EN  > 0u
    OS_ERR  err;


    OSTimeDlyHMSM(0u, 0u, 0u, ms,
                  OS_OPT_TIME_HMSM_STRICT,
                  &err);
    (void)&err;
#endif
}

#endif
#endif
